advertest package
=================

Submodules
----------

advertest.ad\_create module
---------------------------

.. automodule:: advertest.ad_create
    :members:
    :undoc-members:
    :show-inheritance:

advertest.ad\_from\_string module
---------------------------------

.. automodule:: advertest.ad_from_string
    :members:
    :undoc-members:
    :show-inheritance:

advertest.cli module
--------------------

.. automodule:: advertest.cli
    :members:
    :undoc-members:
    :show-inheritance:

advertest.kw\_generate module
-----------------------------

.. automodule:: advertest.kw_generate
    :members:
    :undoc-members:
    :show-inheritance:

advertest.stopwords module
--------------------------

.. automodule:: advertest.stopwords
    :members:
    :undoc-members:
    :show-inheritance:

advertest.url\_builders module
------------------------------

.. automodule:: advertest.url_builders
    :members:
    :undoc-members:
    :show-inheritance:

advertest.word\_frequency module
--------------------------------

.. automodule:: advertest.word_frequency
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: advertest
    :members:
    :undoc-members:
    :show-inheritance:
